@@ -103,7 +103,7 @@ def schema_args(schema_getter, omit=None):
     typemap = {
         'string': encodeutils.safe_decode,
         'integer': int,
-        'boolean': strutils.bool_from_string,
+        'boolean': lambda x: strutils.bool_from_string(x, strict=True),
         'array': list
     }
 
@@ -123,6 +123,8 @@ def schema_args(schema_getter, omit=None):
             for name, property in properties.items():
                 if name in omit:
                     continue
+                if property.get('readOnly', False):
+                    continue
                 param = '--' + name.replace('_', '-')
                 kwargs = {}
 
@@ -269,34 +271,11 @@ def print_list(objs, fields, formatters=None, field_settings=None):
                 field_name = field.lower().replace(' ', '_')
                 data = getattr(o, field_name, None) or ''
                 row.append(data)
-        count = 0
-        # Converts unicode values in list to string
-        for part in row:
-            count = count + 1
-            if isinstance(part, list):
-                part = unicode_key_value_to_string(part)
-                row[count - 1] = part
         pt.add_row(row)
 
     print(encodeutils.safe_decode(pt.get_string()))
 
 
-def _encode(src):
-    """remove extra 'u' in PY2."""
-    return src
-
-
-def unicode_key_value_to_string(src):
-    """Recursively converts dictionary keys to strings."""
-    if isinstance(src, dict):
-        return dict((_encode(k),
-                    _encode(unicode_key_value_to_string(v)))
-                    for k, v in src.items())
-    if isinstance(src, list):
-        return [unicode_key_value_to_string(l) for l in src]
-    return _encode(src)
-
-
 def print_dict(d, max_column_width=80):
     pt = prettytable.PrettyTable(['Property', 'Value'], caching=False)
     pt.align = 'l'
@@ -447,7 +426,7 @@ def get_data_file(args):
         except OSError:
             # (1) stdin is not valid (closed...)
             return None
-        if not sys.stdin.isatty():
+        if hasattr(sys.stdin, 'isatty') and not sys.stdin.isatty():
             # (2) image data is provided through standard input
             image = sys.stdin
             if hasattr(sys.stdin, 'buffer'):
