@@ -45,6 +45,7 @@ import json
 DEFAULT_IMAGE_URL = 'http://127.0.0.1:9292/'
 DEFAULT_IMAGE_URL_INTERNAL = 'http://127.0.0.1:9191/'
 DEFAULT_USERNAME = 'username'
+DEFAULT_PAGE_SIZE = 200
 DEFAULT_PASSWORD = 'password'
 DEFAULT_TENANT_ID = 'tenant_id'
 DEFAULT_TENANT_NAME = 'tenant_name'
@@ -600,6 +601,17 @@ class ShellTest(testutils.TestCase):
         self.assertEqual(glance_logger.getEffectiveLevel(), logging.DEBUG)
         conf.assert_called_with(level=logging.DEBUG)
 
+    def test_subcommand_help(self):
+        # Ensure that main works with sub command help
+        stdout, stderr = self.shell('help stores-delete')
+
+        expected = 'usage: glance stores-delete --store <STORE_ID> ' \
+                   '<IMAGE_ID>\n\nDelete image from specific store.' \
+                   '\n\nPositional arguments:\n  <IMAGE_ID>          ' \
+                   'ID of image to update.\n\nRequired arguments:\n  ' \
+                   '--store <STORE_ID>  Store to delete image from.\n'
+        self.assertEqual(expected, stdout)
+
 
 class ShellTestWithKeystoneV3Auth(ShellTest):
     # auth environment to use
@@ -700,7 +712,8 @@ class ShellTestWithNoOSImageURLPublic(ShellTestWithKeystoneV3Auth):
         glance_shell = openstack_shell.OpenStackImagesShell()
         glance_shell.main(args.split())
         self.assertEqual(self.requests.request_history[2].url,
-                         self.image_url + "v2/images?limit=20&"
+                         self.image_url + "v2/images?"
+                         f"limit={DEFAULT_PAGE_SIZE}&"
                          "sort_key=name&sort_dir=asc")
 
 
