@@ -24,7 +24,7 @@ from glanceclient.common import utils
 from glanceclient import exc
 from glanceclient.v2 import schemas
 
-DEFAULT_PAGE_SIZE = 20
+DEFAULT_PAGE_SIZE = 200
 
 SORT_DIR_VALUES = ('asc', 'desc')
 SORT_KEY_VALUES = ('name', 'status', 'container_format', 'disk_format',
@@ -353,8 +353,9 @@ class Controller(object):
 
     @utils.add_req_id_to_object()
     def image_import(self, image_id, method='glance-direct', uri=None,
-                     backend=None, stores=None, allow_failure=True,
-                     all_stores=None):
+                     remote_region=None, remote_image_id=None,
+                     remote_service_interface=None, backend=None,
+                     stores=None, allow_failure=True, all_stores=None):
         """Import Image via method."""
         headers = {}
         url = '/v2/images/%s/import' % image_id
@@ -370,6 +371,13 @@ class Controller(object):
             if allow_failure:
                 data['all_stores_must_succeed'] = False
 
+        if remote_region and remote_image_id:
+            if remote_service_interface:
+                data['method']['glance_service_interface'] = \
+                    remote_service_interface
+            data['method']['glance_region'] = remote_region
+            data['method']['glance_image_id'] = remote_image_id
+
         if uri:
             if method == 'web-download':
                 data['method']['uri'] = uri
