@@ -778,9 +778,9 @@ def do_image_import(gc, args):
     all_stores = getattr(args, "os_all_stores", None)
     allow_failure = getattr(args, "os_allow_failure", True)
     uri = getattr(args, "uri", None)
-    remote_region = getattr(args, "remote-region", None)
-    remote_image_id = getattr(args, "remote-image-id", None)
-    remote_service_interface = getattr(args, "remote-service-interface", None)
+    remote_region = getattr(args, "remote_region", None)
+    remote_image_id = getattr(args, "remote_image_id", None)
+    remote_service_interface = getattr(args, "remote_service_interface", None)
 
     if not getattr(args, 'from_create', False):
         if (args.store and (stores or all_stores)) or (stores and all_stores):
@@ -801,10 +801,14 @@ def do_image_import(gc, args):
     if getattr(args, 'from_create', False):
         # this command is being called "internally" so we can skip
         # validation -- just do the import and get out of here
-        gc.images.image_import(args.id, args.import_method, args.uri,
-                               backend=backend,
-                               stores=stores, all_stores=all_stores,
-                               allow_failure=allow_failure)
+        gc.images.image_import(
+            args.id, args.import_method, args.uri,
+            remote_region=remote_region,
+            remote_image_id=remote_image_id,
+            remote_service_interface=remote_service_interface,
+            backend=backend,
+            stores=stores, all_stores=all_stores,
+            allow_failure=allow_failure)
         return
 
     # do input validation
@@ -834,6 +838,9 @@ def do_image_import(gc, args):
     if remote_image_id and args.import_method != 'glance-download':
         utils.exit("Import method should be 'glance-download' if "
                    "REMOTE IMAGE ID is provided.")
+    if remote_service_interface and args.import_method != 'glance-download':
+        utils.exit("Import method should be 'glance-download' if "
+                   "REMOTE SERVICE INTERFACE is provided.")
 
     if args.import_method == 'copy-image' and not (stores or all_stores):
         utils.exit("Provide either --stores or --all-stores for "
@@ -1215,6 +1222,8 @@ def do_md_namespace_resource_type_list(gc, args):
            help=_('Property name displayed to the user.'))
 @utils.arg('--schema', metavar='<SCHEMA>', required=True,
            help=_('Valid JSON schema of a property.'))
+@utils.arg('--type', metavar='<TYPE>', required=True,
+           help=_('Type of the property'))
 def do_md_property_create(gc, args):
     """Create a new metadata definitions property inside a namespace."""
     try:
@@ -1222,7 +1231,7 @@ def do_md_property_create(gc, args):
     except ValueError:
         utils.exit('Schema is not a valid JSON object.')
     else:
-        fields = {'name': args.name, 'title': args.title}
+        fields = {'name': args.name, 'title': args.title, 'type': args.type}
         fields.update(schema)
         new_property = gc.metadefs_property.create(args.namespace, **fields)
         utils.print_dict(new_property)
